/*
 * Copyright 2019 Google, LLC
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.netflix.spinnaker.fiat.providers;

import com.netflix.spinnaker.fiat.model.resources.Permissions;
import com.netflix.spinnaker.fiat.model.resources.Resource;
import java.util.Optional;
import javax.annotation.Nonnull;

public final class AccessControlledResourcePermissionSource<T extends Resource.AccessControlled>
    implements ResourcePermissionSource<T> {

  @Override
  @Nonnull
  public Permissions getPermissions(@Nonnull T resource) {
    return Optional.ofNullable(resource)
        .map(Resource.AccessControlled::getPermissions)
        .filter(Permissions::isRestricted)
        .orElse(Permissions.EMPTY);
  }
}
